pub struct UserData {
pub file_archives: HashMap<ArchiveAddress, String>,
pub private_file_archives: HashMap<PrivateArchiveDataMap, String>,
pub register_addresses: HashMap<RegisterAddress, String>,
pub register_key: Option<RegisterSecretKeyHex>,
pub scratchpad_key: Option<ScratchpadSecretKeyHex>,
pub pointer_key: Option<PointerSecretKeyHex>,
pub public_files: HashMap<DataAddress, String>,
pub private_files: HashMap<DataMapChunk, String>,
}Expand description
UserData is stored in Vaults and contains most of a user’s private data: It allows users to keep track of only the key to their User Data Vault while having the rest kept on the Network encrypted in a Vault for them Using User Data Vault is optional, one can decide to keep all their data locally instead.
Fields
file_archives: HashMap<ArchiveAddress, String>Owned file archive addresses, along with their names (can be empty)
private_file_archives: HashMap<PrivateArchiveDataMap, String>Owned private file archives, along with their names (can be empty)
register_addresses: HashMap<RegisterAddress, String>Owned register addresses, along with their names (can be empty)
register_key: Option<RegisterSecretKeyHex>Register key
scratchpad_key: Option<ScratchpadSecretKeyHex>Scratchpads key
pointer_key: Option<PointerSecretKeyHex>Pointer key
public_files: HashMap<DataAddress, String>Individual public files (non-archive), along with their names
private_files: HashMap<DataMapChunk, String>Individual private files (non-archive), along with their names
Implementations
Sourceimpl UserData
impl UserData
Sourcepub fn add_register(
&mut self,
register: RegisterAddress,
name: String,
) -> Option<String>
pub fn add_register( &mut self, register: RegisterAddress, name: String, ) -> Option<String>
Add a register. Returning Option::Some with the old name if the register was already in the set.
Sourcepub fn add_file_archive(&mut self, archive: ArchiveAddress) -> Option<String>
pub fn add_file_archive(&mut self, archive: ArchiveAddress) -> Option<String>
Add an archive. Returning Option::Some with the old name if the archive was already in the set.
Sourcepub fn add_file_archive_with_name(
&mut self,
archive: ArchiveAddress,
name: String,
) -> Option<String>
pub fn add_file_archive_with_name( &mut self, archive: ArchiveAddress, name: String, ) -> Option<String>
Add an archive. Returning Option::Some with the old name if the archive was already in the set.
Sourcepub fn add_private_file_archive(
&mut self,
archive: PrivateArchiveDataMap,
) -> Option<String>
pub fn add_private_file_archive( &mut self, archive: PrivateArchiveDataMap, ) -> Option<String>
Add a private archive. Returning Option::Some with the old name if the archive was already in the set.
Sourcepub fn add_private_file_archive_with_name(
&mut self,
archive: PrivateArchiveDataMap,
name: String,
) -> Option<String>
pub fn add_private_file_archive_with_name( &mut self, archive: PrivateArchiveDataMap, name: String, ) -> Option<String>
Add a private archive with a name. Returning Option::Some with the old name if the archive was already in the set.
Sourcepub fn remove_file_archive(&mut self, archive: ArchiveAddress) -> Option<String>
pub fn remove_file_archive(&mut self, archive: ArchiveAddress) -> Option<String>
Remove an archive. Returning Option::Some with the old name if the archive was already in the set.
Sourcepub fn remove_private_file_archive(
&mut self,
archive: PrivateArchiveDataMap,
) -> Option<String>
pub fn remove_private_file_archive( &mut self, archive: PrivateArchiveDataMap, ) -> Option<String>
Remove a private archive. Returning Option::Some with the old name if the archive was already in the set.
Sourcepub fn from_bytes(bytes: Bytes) -> Result<Self, Error>
pub fn from_bytes(bytes: Bytes) -> Result<Self, Error>
From bytes
Sourcepub fn display_stats(&self)
pub fn display_stats(&self)
Display content